==> seedsui-react-5.7.93.tgz: package/lib/DatePicker/RangeMain/CustomCombo.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
import React from 'react';
import locale from "./../../locale";
// 测试使用
// import locale from 'seedsui-react/lib/locale'

import Combo from "./../Combo";

// 日期快捷选择
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
export default function CustomCombo(_ref) {
  var portal = _ref.portal,
    DateProps = _ref.DateProps,
    _ref$allowClear = _ref.allowClear,
    allowClear = _ref$allowClear === void 0 ? 'exclusion-ricon' : _ref$allowClear,
    value = _ref.value,
    onChange = _ref.onChange,
    onError = _ref.onError;
  // 开始和结束日期
  var startDate = Array.isArray(value) && value[0] instanceof Date ? value[0] : '';
  var endDate = Array.isArray(value) && value[1] instanceof Date ? value[1] : '';

  // 修改开始日期
  function handleStartDateChange(startDate) {
    if (onChange) onChange([startDate, (value === null || value === void 0 ? void 0 : value[1]) || null]);
  }
  // 修改结束日期
  function handleEndDateChange(endDate) {
    if (onChange) onChange([(value === null || value === void 0 ? void 0 : value[0]) || null, endDate]);
  }
  return /*#__PURE__*/_jsxs("div", {
    className: "datepicker-rangemain-custom",
    children: [/*#__PURE__*/_jsx(Combo, _objectSpread({
      portal: portal,
      value: startDate,
      max: Array.isArray(value) && value.length === 2 ? value[1] : undefined,
      onError: onError,
      onChange: handleStartDateChange,
      placeholder: locale('请选择', 'ZKGJ001848'),
      allowClear: allowClear,
      ricon: /*#__PURE__*/_jsx("i", {
        className: "ricon icon shape-arrow-right sm",
        style: {
          marginRight: '4px'
        }
      })
    }, DateProps)), "\u2014", /*#__PURE__*/_jsx(Combo, _objectSpread({
      portal: portal,
      value: endDate,
      min: Array.isArray(value) && value.length === 2 ? value[0] : undefined,
      onError: onError,
      onChange: handleEndDateChange,
      placeholder: locale('请选择', 'ZKGJ001848'),
      allowClear: allowClear,
      ricon: /*#__PURE__*/_jsx("i", {
        className: "ricon icon shape-arrow-right sm",
        style: {
          marginRight: '4px'
        }
      })
    }, DateProps))]
  });
}

==> seedsui-react-5.8.2.tgz: package/lib/DatePicker/RangeMain/CustomCombo.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
import React from 'react';
import locale from "./../../locale";
// 测试使用
// import locale from 'seedsui-react/lib/locale'

import Combo from "./../Combo";

// 日期快捷选择
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
export default function CustomCombo(_ref) {
  var portal = _ref.portal,
    DateProps = _ref.DateProps,
    allowClear = _ref.allowClear,
    value = _ref.value,
    _onBeforeChange = _ref.onBeforeChange,
    _onChange = _ref.onChange,
    onError = _ref.onError;
  // 开始和结束日期
  var startDate = Array.isArray(value) && value[0] instanceof Date ? value[0] : null;
  var endDate = Array.isArray(value) && value[1] instanceof Date ? value[1] : null;
  return /*#__PURE__*/_jsxs("div", {
    className: "datepicker-rangemain-custom",
    children: [/*#__PURE__*/_jsx(Combo, _objectSpread({
      portal: portal,
      value: startDate,
      max: Array.isArray(value) && value.length === 2 ? value[1] : undefined,
      onError: onError,
      onBeforeChange: function onBeforeChange(argStartDate) {
        var newStartDate = argStartDate || null;
        if (_onBeforeChange) {
          return _onBeforeChange(newStartDate || endDate ? [newStartDate, endDate] : null);
        }
      },
      onChange: function onChange(argStartDate) {
        var newStartDate = argStartDate || null;
        if (_onChange) _onChange(newStartDate || endDate ? [newStartDate, endDate] : null);
      },
      placeholder: locale('请选择', 'ZKGJ001848'),
      allowClear: allowClear,
      ricon: /*#__PURE__*/_jsx("i", {
        className: "ricon icon shape-arrow-right sm",
        style: {
          marginRight: '4px'
        }
      })
    }, DateProps)), "\u2014", /*#__PURE__*/_jsx(Combo, _objectSpread({
      portal: portal,
      value: endDate,
      min: Array.isArray(value) && value.length === 2 ? value[0] : undefined,
      onError: onError,
      onBeforeChange: function onBeforeChange(argEndDate) {
        var newEndDate = argEndDate || null;
        if (_onBeforeChange) {
          return _onBeforeChange(startDate || newEndDate ? [startDate, newEndDate] : null);
        }
      },
      onChange: function onChange(argEndDate) {
        var newEndDate = argEndDate || null;
        if (_onChange) _onChange(startDate || newEndDate ? [startDate, newEndDate] : null);
      },
      placeholder: locale('请选择', 'ZKGJ001848'),
      allowClear: allowClear,
      ricon: /*#__PURE__*/_jsx("i", {
        className: "ricon icon shape-arrow-right sm",
        style: {
          marginRight: '4px'
        }
      })
    }, DateProps))]
  });
}
